@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-use YAML::XS qw(LoadFile);
+use YAML::CacheLoader qw(LoadFile);
 
 my $input_yml       = shift or die "YAML file needed as input param";
 my $underlyings = LoadFile($input_yml);
